#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "ostdb.h"
#include "loadfile.h"
#include "loadutils.h"
#include "cdbs_sql_gen.h"

/*
******************************************************************************
*
* Function:     get_new_equiv_class
*
* Purpose:      Gets the current equivalence class value from the database, 
*               increments and updates that value in the database
*               then returns the new moderate and severe values.
*
*               The following query is performed:
*
*               SELECT value 
*               FROM equiv_class_value
*               UPDATE equiv_class_value SET value = value + 2              
*
* Returns:      a pointer to an EquivClass structure containing the new 
*               equivalence class info if successful
*               NULL if not successful 
*
******************************************************************************
*/

EquivClass *get_new_equiv_class (void){

  int equiv_class_val, rec_count;
  EquivClass *new_equiv;
  new_equiv = (EquivClass *)malloc(sizeof(EquivClass));

  // Query the database for the equivalence class info
  //
  ostdb_query_setup(STDB_CONN_1, "get_new_equiv_class", 1, STDB_SQL, 
		    "CDBS_SERVER", "CDBS_DB", NULL);

  stdb_bind_int(STDB_CONN_1, "value", &equiv_class_val);

  stdb_query(STDB_CONN_1, "SELECT value FROM equiv_class_value");
  stdb_query(STDB_CONN_1, "UPDATE equiv_class_value set value=value+2");
  while(ostdb_get_exec(STDB_CONN_1) == STDB_CONTINUE){
    ;
  }
  rec_count = stdb_record_count(STDB_CONN_1);

  stdb_close_query(STDB_CONN_1);
  
  if ((ostdb_get_status(STDB_CONN_1) != OSTDB_NORMAL) || (rec_count != 1)){
    free(new_equiv);
    return(NULL);
  }else{
    new_equiv->sev = equiv_class_val +1;
    new_equiv->mod = equiv_class_val +2;
    return(new_equiv);
  }
}
